@@ -306,8 +306,6 @@ impl Decrypter {
                 true
             }
             QueryView::Duration(ref mut q) => {
-                use std::convert::TryInto;
-
                 if q.format() != gst::Format::Bytes {
                     return pad.query_default(Some(element), query);
                 }
@@ -600,14 +598,14 @@ impl ObjectImpl for Decrypter {
     fn properties() -> &'static [glib::ParamSpec] {
         static PROPERTIES: Lazy<Vec<glib::ParamSpec>> = Lazy::new(|| {
             vec![
-                glib::ParamSpec::new_boxed(
+                glib::ParamSpecBoxed::new(
                     "receiver-key",
                     "Receiver Key",
                     "The private key of the Reeiver",
                     glib::Bytes::static_type(),
                     glib::ParamFlags::READWRITE,
                 ),
-                glib::ParamSpec::new_boxed(
+                glib::ParamSpecBoxed::new(
                     "sender-key",
                     "Sender Key",
                     "The public key of the Sender",
@@ -661,6 +659,8 @@ impl ObjectImpl for Decrypter {
     }
 }
 
+impl GstObjectImpl for Decrypter {}
+
 impl ElementImpl for Decrypter {
     fn metadata() -> Option<&'static gst::subclass::ElementMetadata> {
         static ELEMENT_METADATA: Lazy<gst::subclass::ElementMetadata> = Lazy::new(|| {
