@@ -284,8 +284,6 @@ impl Encrypter {
                 true
             }
             QueryView::Duration(ref mut q) => {
-                use std::convert::TryInto;
-
                 if q.format() != gst::Format::Bytes {
                     return pad.query_default(Some(element), query);
                 }
@@ -392,21 +390,21 @@ impl ObjectImpl for Encrypter {
     fn properties() -> &'static [glib::ParamSpec] {
         static PROPERTIES: Lazy<Vec<glib::ParamSpec>> = Lazy::new(|| {
             vec![
-                glib::ParamSpec::new_boxed(
+                glib::ParamSpecBoxed::new(
                     "receiver-key",
                     "Receiver Key",
                     "The public key of the Receiver",
                     glib::Bytes::static_type(),
                     glib::ParamFlags::READWRITE,
                 ),
-                glib::ParamSpec::new_boxed(
+                glib::ParamSpecBoxed::new(
                     "sender-key",
                     "Sender Key",
                     "The private key of the Sender",
                     glib::Bytes::static_type(),
                     glib::ParamFlags::WRITABLE,
                 ),
-                glib::ParamSpec::new_uint(
+                glib::ParamSpecUInt::new(
                     "block-size",
                     "Block Size",
                     "The block-size of the chunks",
@@ -472,6 +470,8 @@ impl ObjectImpl for Encrypter {
     }
 }
 
+impl GstObjectImpl for Encrypter {}
+
 impl ElementImpl for Encrypter {
     fn metadata() -> Option<&'static gst::subclass::ElementMetadata> {
         static ELEMENT_METADATA: Lazy<gst::subclass::ElementMetadata> = Lazy::new(|| {
